package com.sample;

import org.drools.KnowledgeBase;
import org.drools.SystemEventListenerFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.runtime.StatefulKnowledgeSession;
import org.jbpm.process.workitem.wsht.HornetQHTWorkItemHandler;
import org.jbpm.process.workitem.wsht.WSHumanTaskHandler;
import org.jbpm.task.service.TaskService;
import org.jbpm.task.service.hornetq.CommandBasedHornetQWSHumanTaskHandler;
import org.jbpm.task.service.mina.MinaTaskServer;
import org.jbpm.test.JBPMHelper;

import java.util.Map;
import java.util.HashMap;

import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

/**
 * This is a sample file to launch a process.
 */
public class ProcessMain {

	public static final void main(String[] args) throws Exception {
		startUp();
		// load up the knowledge base
		KnowledgeBase kbase = readKnowledgeBase();
		/*StatefulKnowledgeSession ksession = kbase.newStatefulKnowledgeSession();*/
		StatefulKnowledgeSession ksession = JBPMHelper.newStatefulKnowledgeSession(kbase);
		ksession.getWorkItemManager().registerWorkItemHandler("User Task", new WSHumanTaskHandler());
		ksession.getWorkItemManager().registerWorkItemHandler("Preparation", new Preparation());
		ksession.getWorkItemManager().registerWorkItemHandler("JobArchiveWrite", new JobArchiveWrite(ksession));
		ksession.getWorkItemManager().registerWorkItemHandler("WriteStatus", new WriteStatus());
		
		Map<String, Object> param= new HashMap<String, Object>();
		param.put("retry", true);
		param.put("result", false);
		// start a new process instance
		ksession.startProcess("com.sample.bpmn", param);
		

		
	}

	private static KnowledgeBase readKnowledgeBase() throws Exception {
		KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
		kbuilder.add(ResourceFactory.newClassPathResource("sample2.bpmn"), ResourceType.BPMN2);
		return kbuilder.newKnowledgeBase();
	}
	
	private static void startUp() {
		JBPMHelper.startH2Server();
		JBPMHelper.setupDataSource();
		// please comment this line if you already have the task service running,
		// for example when running the jbpm-installer
		/*JBPMHelper.startTaskService();*/
		EntityManagerFactory emf = Persistence.createEntityManagerFactory("org.jbpm.task");
		TaskService taskService = new TaskService(emf, SystemEventListenerFactory.getSystemEventListener());
		MinaTaskServer server = new MinaTaskServer( taskService );
		Thread thread = new Thread( server );
		thread.start();
	}
	
/*	private static StatefulKnowledgeSession createKnowledgeSession(KnowledgeBase kbase) {
		StatefulKnowledgeSession ksession = kbase.newStatefulKnowledgeSession();
		HornetQHTWorkItemHandler humanTaskHandler = new HornetQHTWorkItemHandler(ksession);
		humanTaskHandler.setIpAddress("127.0.0.1");
		humanTaskHandler.setPort(5445);
		ksession.getWorkItemManager().registerWorkItemHandler("User Task", humanTaskHandler);
		return ksession;
	}*/
	
}